@@ -259,7 +259,9 @@ class DockerCommand(Command):
             -i          Attach this terminal's stdin to the running process
             -m BYTES    Amount of memory, rounded to nearest Orchard container size
                         (in bytes with SI suffix) [default: 512M]
-            -p PORT     Expose a container's port to the host
+            -p PORT     Expose a container's port to the host. In the format 
+                        public:private. If the public port is omitted, a random
+                        port will be assigned.
             -t          Allocate a pseudo-tty
             -v PATH     Mount a volume at the specified path (e.g. /var/lib/mysql)
         """
@@ -267,7 +269,6 @@ class DockerCommand(Command):
         ports = self._get_ports(options)
 
         # Volumes
-        binds = None
         volumes = None
 
         if options['-v']:
@@ -277,7 +278,6 @@ class DockerCommand(Command):
                 sys.stderr.write("HOST:CONTAINER path format is not currently supported - you can only specify the container path.\n")
                 exit(1)
 
-            binds = {"":path}
             volumes = {path:{}}
 
         if options['IMAGE'] != 'ubuntu':
@@ -311,17 +311,24 @@ class DockerCommand(Command):
             mem_limit=mem_limit
         )
 
+        container = self.docker.inspect_container(container['Id'])
+
+        binds = {}
+        if container['Config'].get('Volumes'):
+            for (path, _) in container['Config']['Volumes'].items():
+                binds[""] = path
+
         if options['-d']:
-            self.docker.start(container['Id'], binds=binds)
-            print container['Id']
+            self.docker.start(container['ID'], binds=binds)
+            print container['ID'][:10]
         else:
             with self._attach_to_container(
-                container['Id'],
+                container['ID'],
                 interactive=options['-i'],
                 logs=True,
                 raw=options['-t']
             ) as c:
-                self.docker.start(container['Id'], binds=binds)
+                self.docker.start(container['ID'], binds=binds)
                 c.run()
 
     def start(self, options):
